==> blancoOmegatUtil-0.0.5-src.zip: src/blanco/xliff/valueobject/BlancoXliffAltTrans.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.valueobject;

import java.util.List;

/**
 * OASIS XLIFF  alt-trans 킷o[IuWFNgB
 */
public class BlancoXliffAltTrans {
    /**
     * tB[h [lang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgB
     */
    private String fLang;

    /**
     * tB[h [tool-id]
     *
     * ڂ̌^ [java.lang.String]<br>
     * pleiades, eclipseȂǁB
     */
    private String fToolId;

    /**
     * tB[h [source]
     *
     * ڂ̌^ [java.lang.String]<br>
     */
    private String fSource;

    /**
     * tB[h [target]
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * ^[QbgBXgɂ炸B
     */
    private BlancoXliffTarget fTarget;

    /**
     * tB[h [noteList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * notẽXgB
     */
    private List fNoteList = new java.util.ArrayList();

    /**
     * tB[h [match-quality]
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̈viB%ŋLځB
     */
    private String fMatchQuality;

    /**
     * tB[h [lang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgB
     *
     * @param argLang tB[h[lang]Ɋi[l
     */
    public void setLang(final String argLang) {
        fLang = argLang;
    }

    /**
     * tB[h[lang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgB
     *
     * @return tB[h[lang]Ɋi[Ăl
     */
    public String getLang() {
        return fLang;
    }

    /**
     * tB[h [tool-id]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pleiades, eclipseȂǁB
     *
     * @param argToolId tB[h[tool-id]Ɋi[l
     */
    public void setToolId(final String argToolId) {
        fToolId = argToolId;
    }

    /**
     * tB[h[tool-id]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pleiades, eclipseȂǁB
     *
     * @return tB[h[tool-id]Ɋi[Ăl
     */
    public String getToolId() {
        return fToolId;
    }

    /**
     * tB[h [source]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @param argSource tB[h[source]Ɋi[l
     */
    public void setSource(final String argSource) {
        fSource = argSource;
    }

    /**
     * tB[h[source]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @return tB[h[source]Ɋi[Ăl
     */
    public String getSource() {
        return fSource;
    }

    /**
     * tB[h [target]̃Zb^[\bh
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * ^[QbgBXgɂ炸B
     *
     * @param argTarget tB[h[target]Ɋi[l
     */
    public void setTarget(final BlancoXliffTarget argTarget) {
        fTarget = argTarget;
    }

    /**
     * tB[h[target]̃Qb^[\bh
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * ^[QbgBXgɂ炸B
     *
     * @return tB[h[target]Ɋi[Ăl
     */
    public BlancoXliffTarget getTarget() {
        return fTarget;
    }

    /**
     * tB[h [noteList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * notẽXgB
     *
     * @param argNoteList tB[h[noteList]Ɋi[l
     */
    public void setNoteList(final List argNoteList) {
        fNoteList = argNoteList;
    }

    /**
     * tB[h[noteList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * notẽXgB
     *
     * @return tB[h[noteList]Ɋi[Ăl
     */
    public List getNoteList() {
        return fNoteList;
    }

    /**
     * tB[h [match-quality]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̈viB%ŋLځB
     *
     * @param argMatchQuality tB[h[match-quality]Ɋi[l
     */
    public void setMatchQuality(final String argMatchQuality) {
        fMatchQuality = argMatchQuality;
    }

    /**
     * tB[h[match-quality]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̈viB%ŋLځB
     *
     * @return tB[h[match-quality]Ɋi[Ăl
     */
    public String getMatchQuality() {
        return fMatchQuality;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.valueobject.BlancoXliffAltTrans[");
        buf.append("lang=" + fLang);
        buf.append(",tool-id=" + fToolId);
        buf.append(",source=" + fSource);
        buf.append(",target=" + fTarget);
        buf.append(",noteList=" + fNoteList);
        buf.append(",match-quality=" + fMatchQuality);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoOmegatUtil-0.1.1-src.zip: src/blanco/xliff/valueobject/BlancoXliffAltTrans.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.valueobject;

import java.util.List;

/**
 * OASIS XLIFF  alt-trans 킷o[IuWFNgB
 */
public class BlancoXliffAltTrans {
    /**
     * tB[h [lang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgB
     */
    private String fLang;

    /**
     * tB[h [tool-id]
     *
     * ڂ̌^ [java.lang.String]<br>
     * pleiades, eclipseȂǁB
     */
    private String fToolId;

    /**
     * tB[h [source]
     *
     * ڂ̌^ [java.lang.String]<br>
     */
    private String fSource;

    /**
     * tB[h [target]
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * ^[QbgBXgɂ炸B
     */
    private BlancoXliffTarget fTarget;

    /**
     * tB[h [noteList]
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffNote>]<br>
     * Kl   [new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffNote>()]<br>
     * notẽXgB
     */
    private List<blanco.xliff.valueobject.BlancoXliffNote> fNoteList = new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffNote>();

    /**
     * tB[h [match-quality]
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̈viB%ŋLځB
     */
    private String fMatchQuality;

    /**
     * tB[h [origin]
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃ǂ炫̂B
     */
    private String fOrigin;

    /**
     * tB[h [phase-name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     */
    private String fPhaseName;

    /**
     * tB[h [lang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgB
     *
     * @param argLang tB[h[lang]Ɋi[l
     */
    public void setLang(final String argLang) {
        fLang = argLang;
    }

    /**
     * tB[h[lang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgB
     *
     * @return tB[h[lang]Ɋi[Ăl
     */
    public String getLang() {
        return fLang;
    }

    /**
     * tB[h [tool-id]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pleiades, eclipseȂǁB
     *
     * @param argToolId tB[h[tool-id]Ɋi[l
     */
    public void setToolId(final String argToolId) {
        fToolId = argToolId;
    }

    /**
     * tB[h[tool-id]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pleiades, eclipseȂǁB
     *
     * @return tB[h[tool-id]Ɋi[Ăl
     */
    public String getToolId() {
        return fToolId;
    }

    /**
     * tB[h [source]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @param argSource tB[h[source]Ɋi[l
     */
    public void setSource(final String argSource) {
        fSource = argSource;
    }

    /**
     * tB[h[source]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @return tB[h[source]Ɋi[Ăl
     */
    public String getSource() {
        return fSource;
    }

    /**
     * tB[h [target]̃Zb^[\bh
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * ^[QbgBXgɂ炸B
     *
     * @param argTarget tB[h[target]Ɋi[l
     */
    public void setTarget(final BlancoXliffTarget argTarget) {
        fTarget = argTarget;
    }

    /**
     * tB[h[target]̃Qb^[\bh
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * ^[QbgBXgɂ炸B
     *
     * @return tB[h[target]Ɋi[Ăl
     */
    public BlancoXliffTarget getTarget() {
        return fTarget;
    }

    /**
     * tB[h [noteList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffNote>]<br>
     * notẽXgB
     *
     * @param argNoteList tB[h[noteList]Ɋi[l
     */
    public void setNoteList(final List<blanco.xliff.valueobject.BlancoXliffNote> argNoteList) {
        fNoteList = argNoteList;
    }

    /**
     * tB[h[noteList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffNote>]<br>
     * Kl   [new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffNote>()]<br>
     * notẽXgB
     *
     * @return tB[h[noteList]Ɋi[Ăl
     */
    public List<blanco.xliff.valueobject.BlancoXliffNote> getNoteList() {
        return fNoteList;
    }

    /**
     * tB[h [match-quality]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̈viB%ŋLځB
     *
     * @param argMatchQuality tB[h[match-quality]Ɋi[l
     */
    public void setMatchQuality(final String argMatchQuality) {
        fMatchQuality = argMatchQuality;
    }

    /**
     * tB[h[match-quality]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃̈viB%ŋLځB
     *
     * @return tB[h[match-quality]Ɋi[Ăl
     */
    public String getMatchQuality() {
        return fMatchQuality;
    }

    /**
     * tB[h [origin]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃ǂ炫̂B
     *
     * @param argOrigin tB[h[origin]Ɋi[l
     */
    public void setOrigin(final String argOrigin) {
        fOrigin = argOrigin;
    }

    /**
     * tB[h[origin]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃁃ǂ炫̂B
     *
     * @return tB[h[origin]Ɋi[Ăl
     */
    public String getOrigin() {
        return fOrigin;
    }

    /**
     * tB[h [phase-name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     *
     * @param argPhaseName tB[h[phase-name]Ɋi[l
     */
    public void setPhaseName(final String argPhaseName) {
        fPhaseName = argPhaseName;
    }

    /**
     * tB[h[phase-name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     *
     * @return tB[h[phase-name]Ɋi[Ăl
     */
    public String getPhaseName() {
        return fPhaseName;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.valueobject.BlancoXliffAltTrans[");
        buf.append("lang=" + fLang);
        buf.append(",tool-id=" + fToolId);
        buf.append(",source=" + fSource);
        buf.append(",target=" + fTarget);
        buf.append(",noteList=" + fNoteList);
        buf.append(",match-quality=" + fMatchQuality);
        buf.append(",origin=" + fOrigin);
        buf.append(",phase-name=" + fPhaseName);
        buf.append("]");
        return buf.toString();
    }
}
